==> thirdparty-service-biz-0.0.9.10-20180319.064614-2-sources.jar: cn/com/duiba/biz/phonebill/supplier/NewLianLianPhonebillSupplier.java <==
package cn.com.duiba.biz.phonebill.supplier;

import cn.com.duiba.domain.MessageUniqueCheckDO;
import cn.com.duiba.domain.SupplierRequest;
import cn.com.duiba.domain.SupplierResponse;
import cn.com.duiba.service.HttpAsyncClientPool;
import cn.com.duiba.service.MessageService;
import cn.com.duiba.tool.HttpRequestLog;
import cn.com.duiba.tool.JsonTool;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.entity.StringEntity;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 连连接口请求
 */
@Service
public class NewLianLianPhonebillSupplier {

	private static Logger log = LoggerFactory.getLogger(NewLianLianPhonebillSupplier.class);
	
	@Autowired
	private MessageService messageService;
	@Autowired
	private HttpAsyncClientPool httpAsyncClientPool;

	/**
	 * 提交到HTTP请求池
	 * @param message
	 * @param callbackTopic
	 * @param msgTag
	 * @param msgKey
	 */
	public void asyncSubmit(final SupplierRequest message, final String callbackTopic, final String msgTag, final String msgKey) {
		if(!messageService.messageUniqueCheck(message.getSupplierOrderId(), MessageUniqueCheckDO.TYPE_PHONEBILL)){
			return;
		}
		HttpPost post = new HttpPost(message.getHttpUrl());
		String bodyContent = message.getParams().get("entity");
		StringEntity entity = new StringEntity(bodyContent, "UTF-8");
		entity.setContentType("application/json;charset=UTF-8");
		post.setEntity(entity);
		post.addHeader("Accept", "application/json");
		post.addHeader("ContentType", "application/json;charset=UTF-8");
		
		HttpRequestLog.logUrl("[action phonebill] [tag request] [bizId " + message.getOrderId() + "] [url " + message.getHttpUrl() + "]");
		httpAsyncClientPool.submit(message.getAppId(), post, new FutureCallback<HttpResponse>() {

			@Override
			public void completed(HttpResponse response) {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setSupplierName(message.getSupplierName());
					resp.setUrl(message.getHttpUrl());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_COMPLETED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					String body = EntityUtils.toString(response.getEntity());
					resp.setBody(body);
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void failed(Exception ex) {
				log.error("NewLianLianPhonebillSupplier failed orderId:" + message.getOrderId(), ex);
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_FAILED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					resp.setErrorMessage(ex.getClass().getName() + ":" + ex.getMessage());
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void cancelled() {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_CANCELLED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier cancelled", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

		});

	}
	
	private void finallyBlock(SupplierRequest message, SupplierResponse response, String callbackTopic, String msgTag, String msgKey) {
		try {
			response.setUrl(message.getHttpUrl());
			response.setSupplierName(message.getSupplierName());
			response.setSupplierOrderId(message.getSupplierOrderId());
			response.setOrderId(message.getOrderId());
			response.setAppId(message.getAppId());
			response.setConsumerId(message.getConsumerId());
			String body = JsonTool.objectToJson(response);
			HttpRequestLog.logUrl("[action phonebill] [tag response] [callback " + response.getCallbackType() + "] [bizId " + message.getOrderId() + "] [body " + response.getBody() + "]");
			messageService.sendMsg(callbackTopic, msgTag, msgKey, body);
		} catch (Exception e) {
			log.error("NewLianLianPhonebillSupplier callback:" + message.getOrderId(), e);
		}
	}

}

==> thirdparty-service-biz-1.0.33.1-20210906.061255-2-sources.jar: cn/com/duiba/biz/phonebill/supplier/NewLianLianPhonebillSupplier.java <==
package cn.com.duiba.biz.phonebill.supplier;

import cn.com.duiba.domain.MessageUniqueCheckDO;
import cn.com.duiba.domain.SupplierRequest;
import cn.com.duiba.domain.SupplierResponse;
import cn.com.duiba.mq.RocketMQMsgProducer;
import cn.com.duiba.service.HttpAsyncClientPool;
import cn.com.duiba.service.MessageService;
import cn.com.duiba.tool.HttpRequestLog;
import cn.com.duiba.tool.JsonTool;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.entity.StringEntity;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 连连接口请求
 */
@Service
public class NewLianLianPhonebillSupplier {

	private static Logger log = LoggerFactory.getLogger(NewLianLianPhonebillSupplier.class);

	@Autowired
	private RocketMQMsgProducer rocketMQMsgProducer;
	@Autowired
	private MessageService messageService;
	@Autowired
	private HttpAsyncClientPool httpAsyncClientPool;

	/**
	 * 提交到HTTP请求池
	 * @param message
	 * @param callbackTopic
	 * @param msgTag
	 * @param msgKey
	 */
	public void asyncSubmit(final SupplierRequest message, final String callbackTopic, final String msgTag, final String msgKey) {
		if(!messageService.messageUniqueCheck(message.getSupplierOrderId(), MessageUniqueCheckDO.TYPE_PHONEBILL)){
			return;
		}
		HttpPost post = new HttpPost(message.getHttpUrl());
		String bodyContent = message.getParams().get("entity");
		StringEntity entity = new StringEntity(bodyContent, "UTF-8");
		entity.setContentType("application/json;charset=UTF-8");
		post.setEntity(entity);
		post.addHeader("Accept", "application/json");
		post.addHeader("ContentType", "application/json;charset=UTF-8");
		
		HttpRequestLog.logUrl("[action phonebill] [tag request] [bizId " + message.getOrderId() + "] [url " + message.getHttpUrl() + "]");
		httpAsyncClientPool.submit(message.getAppId(), post, new FutureCallback<HttpResponse>() {

			@Override
			public void completed(HttpResponse response) {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setSupplierName(message.getSupplierName());
					resp.setUrl(message.getHttpUrl());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_COMPLETED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					String body = EntityUtils.toString(response.getEntity());
					resp.setBody(body);
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void failed(Exception ex) {
				log.error("NewLianLianPhonebillSupplier failed orderId:" + message.getOrderId(), ex);
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_FAILED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					resp.setErrorMessage(ex.getClass().getName() + ":" + ex.getMessage());
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void cancelled() {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_CANCELLED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
				} catch (Exception e) {
					log.error("NewLianLianPhonebillSupplier cancelled", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

		});

	}
	
	private void finallyBlock(SupplierRequest message, SupplierResponse response, String callbackTopic, String msgTag, String msgKey) {
		try {
			response.setUrl(message.getHttpUrl());
			response.setSupplierName(message.getSupplierName());
			response.setSupplierOrderId(message.getSupplierOrderId());
			response.setOrderId(message.getOrderId());
			response.setAppId(message.getAppId());
			response.setConsumerId(message.getConsumerId());
			String body = JsonTool.objectToJson(response);
			HttpRequestLog.logUrl("[action phonebill] [tag response] [callback " + response.getCallbackType() + "] [bizId " + message.getOrderId() + "] [body " + response.getBody() + "]");
			if(callbackTopic.contains("MQ")){
				rocketMQMsgProducer.sendMsg(callbackTopic, msgTag, msgKey, body,false,null);
			}else{
				messageService.sendMsg(callbackTopic,msgTag,msgKey,body);
			}
		} catch (Exception e) {
			log.error("NewLianLianPhonebillSupplier callback:" + message.getOrderId(), e);
		}
	}

}
